rcparams = {
    "svg.fonttype": "none",
    "pdf.fonttype": 42,
    "savefig.transparent": True,
    "figure.figsize": (4, 4),
    "axes.titlesize": 15,
    "axes.titleweight": 500,
    "axes.titlepad": 8.0,
    "axes.labelsize": 14,
    "axes.labelweight": 500,
    "axes.linewidth": 1.2,
    "axes.labelpad": 6.0,
    "font.size": 11,
    "font.family": "sans-serif",
    "font.sans-serif": [
        "Helvetica",
        "Computer Modern Sans Serif",
        "DejaVU Sans",
    ],
    "font.weight": 500,
    "xtick.labelsize": 12,
    "xtick.minor.size": 1.375,
    "xtick.major.size": 2.75,
    "xtick.major.pad": 2,
    "xtick.minor.pad": 2,
    "ytick.labelsize": 12,
    "ytick.minor.size": 1.375,
    "ytick.major.size": 2.75,
    "ytick.major.pad": 2,
    "ytick.minor.pad": 2,
    "legend.fontsize": 12,
    "legend.handlelength": 1.4,
    "legend.numpoints": 1,
    "legend.scatterpoints": 3,
    "legend.frameon": False,
    "lines.linewidth": 1.7,
}



from typing import Iterable, Union

import matplotlib
import matplotlib.pyplot as plt

import mplscience._styledata
from mplscience._styledata import __all__ as _available_styles


def available_styles() -> str:
    print(_available_styles)


def set_style(name: Union[str, Iterable[str]] = ("default", "despine")) -> None:
    """Set the style.

    Parameters
    ----------
    name
        Available style name
    """

    rcparams_update = {}
    names = [name] if isinstance(name, str) else name

    # compose multiple styles
    for n in names:
        if n not in _available_styles:
            raise ValueError("Style name not understood")
        rcparams_update.update(getattr(mplscience._styledata, n))

    plt.rcParams.update(rcparams_update)


def style_context(name: Union[str, Iterable[str]] = ("default", "despine")):
    """Creates a style context.

    Parameters
    ----------
    name
        Available style name

    Returns
    -------
    A context with selected style
    """

    rcparams = {}
    names = [name] if isinstance(name, str) else name

    # compose multiple styles
    for n in names:
        print(getattr(mplscience._styledata, n))
        rcparams.update(getattr(mplscience._styledata, n))

    return matplotlib.rc_context(rcparams)



"""Matplotlib science style"""

from .core import available_styles, set_style

# https://github.com/python-poetry/poetry/pull/2366#issuecomment-652418094
# https://github.com/python-poetry/poetry/issues/144#issuecomment-623927302
try:
    import importlib.metadata as importlib_metadata
except ModuleNotFoundError:
    import importlib_metadata
package_name = "mplscience"
__version__ = importlib_metadata.version(package_name)


__all__ = ["available_styles", "set_style"]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mplscience', 'mplscience._styledata']

package_data = \
{'': ['*']}

install_requires = \
['matplotlib']

extras_require = \
{':python_version < "3.8"': ['importlib-metadata>=1.0,<2.0']}

setup_kwargs = {
    'name': 'mplscience',
    'version': '0.0.3',
    'description': 'Matplotlib style for scientific publications.',
    'long_description': "# mplscience\n\nMatplotlib style for scientific publications. This style keeps things pretty simple and aims to make moderate improvements to the base matplotlib style. It also sets things like the PDF font type to make it easier to interact with figures in Adobe Illustrator.\n\n\n## Usage\n\n```python\nimport mplscience\nmplscience.available_styles()\nmplscience.set_style()\n```\n\nIf you're using Seaborn, you may want to run `sns.reset_orig()` first to clear Seaborn-specific styling.\n\nThe style can also be using in a context like this:\n\n```python\nimport mplscience\nwith mplscience.style_context():\n    plt.plot(x, y)\n```\n\n",
    'author': 'Adam Gayoso',
    'author_email': 'adamgayoso@berkeley.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/adamgayoso/mplscience',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.6.1,<4.0',
}


setup(**setup_kwargs)
